#!/usr/bin/env python
# encoding: utf-8
"""
An example config file that shows how to compare files where the variables 
have different names in each file.

This specific config file to compares sfc emissivity output from Geocat to 
output from the AIT Framework.

Created by Graeme Martin 2010-11-19.
Copyright (c) 2010 University of Wisconsin SSEC. All rights reserved.
"""

# you will need to import the glance.constants to get the standard names
import glance.constants as constants

# general settings to control how reports are created
settings = {}
settings[constants.DO_CLEAR_MEM_THREADED_KEY] = True
settings[constants.DO_MAKE_IMAGES_KEY]        = True
settings[constants.USE_SHARED_ORIG_RANGE_KEY] = True
settings[constants.DO_MAKE_FORKS_KEY]         = False

# info on the latitude and longitude variables that will be used
lat_lon_info = {}
lat_lon_info[constants.LONGITUDE_NAME_KEY] = 'sounding_land_emiss_Lon_reduced'
lat_lon_info[constants.LATITUDE_NAME_KEY ] = 'sounding_land_emiss_Lat_reduced'
lat_lon_info[constants.LON_ALT_NAME_IN_B_KEY] = 'Longitude' 
lat_lon_info[constants.LAT_ALT_NAME_IN_B_KEY] = 'Latitude'


lat_lon_info[constants.LON_LAT_EPSILON_KEY]  = 0.0001

# per variable defaults
defaultValues = {
    constants.EPSILON_KEY:                None,
    constants.EPSILON_FAIL_TOLERANCE_KEY: None,     
    constants.NONFINITE_TOLERANCE_KEY:    None,
    constants.FILL_VALUE_ALT_IN_B_KEY:    -999.0
    }


# a list of all the variables to analyze
#
setOfVariables = {}

setOfVariables['channel 11 emissivity'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Emiss_ch11',
    constants.VARIABLE_B_TECH_NAME_KEY: 'Emiss_Ch11'
    }

setOfVariables['channel 14 emissivity'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Emiss_ch14',
    constants.VARIABLE_B_TECH_NAME_KEY: 'Emiss_Ch14'
    }

setOfVariables['channel 15 emissivity'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Emiss_ch15',
    constants.VARIABLE_B_TECH_NAME_KEY: 'Emiss_Ch15'
    }

setOfVariables['land surface temperature'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Lst_time3',
    constants.VARIABLE_B_TECH_NAME_KEY: 'LST'
    }

setOfVariables['reduced resolution longitude'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Lon_reduced',
    constants.VARIABLE_B_TECH_NAME_KEY: 'Longitude'
    }

setOfVariables['reduced resolution latitude'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY:   'sounding_land_emiss_Lat_reduced',
    constants.VARIABLE_B_TECH_NAME_KEY: 'Latitude'
    }

